Crate eggplant

Crate eggplant 

Re-exports

pub use egglog;
pub use dashmap;
pub use inventory;
pub use serde;
pub use serde_json;
pub use strum;
pub use strum_macros;

Modules

derive_more
prelude
wrap

Macros

basic_patttern_recorder
basic_tx_minimal
macro to quickly define a minimal Transimitter
basic_tx_no_vt
macro to quickly define a Transimitter with no version control
basic_tx_rx_vt
basic_tx_rx_vt_pr
basic_tx_vt
macro to quickly define a Transimitter with version control
datatype
Transpile macro that converts egglog DSL to Rust code
egglog
Transpile egglog Rewrite into Rust code
rule
Transpile egglog Rewrite into Rust code
tx_rx_vt_pr

Attribute Macros

base_ty
base_ty define,
container
dsl
generate egglog language from rust native structure
func
pat_vars
pattern vars
pat_vars_catch
pattern vars