macro_rules! basic_tx_no_vt {
($name:ident) => { ... };
}Expand description
macro to quickly define a Transimitter with no version control
macro_rules! basic_tx_no_vt {
($name:ident) => { ... };
}macro to quickly define a Transimitter with no version control