Re-exports
pub use egglog;pub use dashmap;pub use inventory;pub use serde;pub use serde_json;pub use strum;pub use strum_macros;
Modules
Macros
- basic_
patttern_ recorder - basic_
tx_ minimal - macro to quickly define a minimal Transimitter
- basic_
tx_ no_ vt - macro to quickly define a Transimitter with no version control
- basic_
tx_ rx_ vt - basic_
tx_ rx_ vt_ pr - basic_
tx_ vt - macro to quickly define a Transimitter with version control
- datatype
- Transpile macro that converts egglog DSL to Rust code
- egglog
- Transpile egglog Rewrite into Rust code
- rule
- Transpile egglog Rewrite into Rust code
- tx_
rx_ vt_ pr